negate
######

.. doxygenfunction:: librapid::Array::operator-() const

---

.. doxygenfunction:: librapid::negate(const Array &a)

---

.. doxygenfunction:: librapid::negate(const Array &a, Array &res)
